==> ejc-procurement-impl-3.0.0-20251215.064109-118-sources.jar: com/ejianc/business/procurement/perform/controller/FileConformanceController.java <==
package com.ejianc.business.procurement.perform.controller;

import java.io.Serializable;

import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.procurement.perform.bean.FileConformanceEntity;
import com.ejianc.business.procurement.perform.service.IFileConformanceService;
import com.ejianc.business.procurement.perform.vo.FileConformanceVO;

/**
 * 资格性符合性审查档案
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("fileConformance")
public class FileConformanceController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());


    @Autowired
    private IFileConformanceService service;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<FileConformanceVO> saveOrUpdate(@RequestBody FileConformanceVO saveOrUpdateVO) {
    	FileConformanceEntity entity = BeanMapper.map(saveOrUpdateVO, FileConformanceEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
        }
    	service.saveOrUpdate(entity, false);
    	FileConformanceVO vo = BeanMapper.map(entity, FileConformanceVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FileConformanceVO> queryDetail(Long id) {
    	FileConformanceEntity entity = service.selectById(id);
    	FileConformanceVO vo = BeanMapper.map(entity, FileConformanceVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<FileConformanceVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (FileConformanceVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(FileConformanceVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<FileConformanceVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));


        IPage<FileConformanceEntity> page = service.queryPage(param,false);
        IPage<FileConformanceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), FileConformanceVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        List<FileConformanceEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("FileConformance-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refFileConformanceData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<FileConformanceVO>> refFileConformanceData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<FileConformanceEntity> page = service.queryPage(param,false);
        IPage<FileConformanceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), FileConformanceVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-procurement-impl-3.0.0-20251215.072252-119-sources.jar: com/ejianc/business/procurement/perform/controller/FileConformanceController.java <==
package com.ejianc.business.procurement.perform.controller;

import java.io.Serializable;

import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.procurement.perform.bean.FileConformanceEntity;
import com.ejianc.business.procurement.perform.service.IFileConformanceService;
import com.ejianc.business.procurement.perform.vo.FileConformanceVO;

/**
 * 资格性符合性审查档案
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("fileConformance")
public class FileConformanceController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());


    @Autowired
    private IFileConformanceService service;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<FileConformanceVO> saveOrUpdate(@RequestBody FileConformanceVO saveOrUpdateVO) {
    	FileConformanceEntity entity = BeanMapper.map(saveOrUpdateVO, FileConformanceEntity.class);
        QueryParam queryParam = new QueryParam();
        queryParam.getParams().put("pid", new Parameter(QueryParam.EQ, entity.getPid()));
        List<FileConformanceEntity> list = service.queryList(queryParam, false);
        if(entity.getId() == null || entity.getId() == 0){
            if(entity.getPid()==null){
                entity.setSecCode((list.size()+1)+"");
            }else {
                FileConformanceEntity parent = service.selectById(entity.getPid());
                entity.setSecCode((parent.getSecCode()+".")+(list.size()+1));
            }
        }
    	service.saveOrUpdate(entity, false);
    	FileConformanceVO vo = BeanMapper.map(entity, FileConformanceVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FileConformanceVO> queryDetail(Long id) {
    	FileConformanceEntity entity = service.selectById(id);
    	FileConformanceVO vo = BeanMapper.map(entity, FileConformanceVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<FileConformanceVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (FileConformanceVO vo : vos) {
                FileConformanceEntity entity = service.selectById(vo.getId());
                if(entity.getLevelNum() == 1){
                    QueryParam queryParam = new QueryParam();
                    queryParam.getParams().put("pid", new Parameter(QueryParam.EQ, entity.getId()));
                    List<FileConformanceEntity> list = service.queryList(queryParam, false);
                    if(ListUtil.isNotEmpty(list)){
                        return CommonResponse.error("请先删除子级数据！");
                    }
                }
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(FileConformanceVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<FileConformanceVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("pid", new Parameter(QueryParam.EQ, null));
        param.getOrderMap().put("secCode", QueryParam.ASC);


        IPage<FileConformanceEntity> page = service.queryPage(param,false);
        IPage<FileConformanceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        List<FileConformanceVO> records = BeanMapper.mapList(page.getRecords(), FileConformanceVO.class);
        if(ListUtil.isNotEmpty(records)){
            for (FileConformanceVO record : records) {
                QueryParam queryParam = new QueryParam();
                queryParam.getParams().put("pid", new Parameter(QueryParam.EQ, record.getId()));
                queryParam.getOrderMap().put("secCode", QueryParam.ASC);
                List<FileConformanceEntity> list = service.queryList(queryParam, false);
                record.setChildren(BeanMapper.mapList(list, FileConformanceVO.class));
            }
        }
  		pageData.setRecords(records);

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        List<FileConformanceEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("FileConformance-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refFileConformanceData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<FileConformanceVO>> refFileConformanceData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("pid", new Parameter(QueryParam.EQ, null));
        param.getOrderMap().put("secCode", QueryParam.ASC);
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<FileConformanceEntity> page = service.queryPage(param,false);
        IPage<FileConformanceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        List<FileConformanceVO> records = BeanMapper.mapList(page.getRecords(), FileConformanceVO.class);
        if(ListUtil.isNotEmpty(records)){
            for (FileConformanceVO record : records) {
                QueryParam queryParam = new QueryParam();
                queryParam.getParams().put("pid", new Parameter(QueryParam.EQ, record.getId()));
                queryParam.getOrderMap().put("secCode", QueryParam.ASC);
                List<FileConformanceEntity> list = service.queryList(queryParam, false);
                record.setChildren(BeanMapper.mapList(list, FileConformanceVO.class));
            }
        }
        pageData.setRecords(records);

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
